package roneditor.actions;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.Request;
import org.eclipse.gef.ui.actions.SelectionAction;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Shell;

import roneditor.RONActivator;
import roneditor.dialogs.CreateHLPlaceOrTokenDialog;
import roneditor.dialogs.HLTransitionPropertiesDialog;
import roneditor.edit.parts.RONTreeEditPart;
import roneditor.editor.RONEditor;
import roneditor.ronview.commands.CreateHLPlaceCommand;
import roneditor.ronview.commands.CreateHLTransitionCommand;
import ronmodel.HLPlaceType;

public class CreateHLTransitionAction extends SelectionAction {

	static public final String ID = "Create HLTransition";

	public CreateHLTransitionAction(final RONEditor part) {
		super(part);
		setId(CreateHLTransitionAction.ID);
		setText("Create HLTRansition");
		setDescription("Create a transition in the RON");
		setToolTipText("Create a transition in the RON");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.action.IAction#run()
	 */
	@Override
	public void run() {
		// create dialog
		final Shell shell = getWorkbenchPart().getSite().getShell();
		HLTransitionPropertiesDialog dialog = new HLTransitionPropertiesDialog(
				shell, SWT.NULL);
		dialog.setTitle("Create transition");
		dialog.open();
		if (dialog.isCancelled()) {
			return;
		}
		CreateHLTransitionCommand createHLTransitionCommand = getCommand();
		createHLTransitionCommand.setName(dialog.getTransitionName());
		createHLTransitionCommand.setKind(dialog.getKind());
		execute(createHLTransitionCommand);
	}

	/**
	 * Gets the command from the selected edit part which delivers a Command for
	 * the ID request since {@link #calculateEnabled()} must have returned true.
	 */
	private CreateHLTransitionCommand getCommand() {
		// HINT Die Action besorgt sich ein Command vom ausgewhlten Editpart
		final Object selection = ((StructuredSelection) getSelection())
				.getFirstElement();
		return (CreateHLTransitionCommand) ((EditPart) selection)
				.getCommand(new Request(ID));
	}

	/**
	 * Calculates whether this action is enabled or not by checking if it
	 * understands the ID request.
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.ui.actions.WorkbenchPartAction#calculateEnabled()
	 */
	@Override
	protected boolean calculateEnabled() {
		// HINT Diese Action soll nur fr genau einen ausgewhlten EditPart
		// angezeigt
		// werden, der auch den Request ID versteht
		if (getSelectedObjects().size() == 1
				&& (getSelectedObjects().get(0) instanceof EditPart)) {
			final EditPart part = (EditPart) getSelectedObjects().get(0);
			return part.understandsRequest(new Request(ID));
		}
		return false;
	}
}
