package roneditor.editor;

import org.eclipse.ui.IFolderLayout;
import org.eclipse.ui.IPageLayout;
import org.eclipse.ui.IPerspectiveFactory;
import org.eclipse.ui.IPlaceholderFolderLayout;

import roneditor.IRonEditorConstants;

/**
 * This the default definition of the perspective for the RON editor.
 * 
 * @author Tony Modica
 */
public class RonEditorPerspective implements IPerspectiveFactory {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.IPerspectiveFactory#createInitialLayout(org.eclipse.ui.IPageLayout)
	 */
	public void createInitialLayout(final IPageLayout layout) {
		defineActions(layout);
		defineLayout(layout);
	}

	/**
	 * Defines the initial actions for a page.
	 * 
	 * @param layout
	 *            The layout we are filling
	 */
	private void defineActions(final IPageLayout layout) {
		layout.addNewWizardShortcut("roneditor.dialogs.RONFileCreationWizard"); //$NON-NLS-1$

		// Add "show views".
		layout.addShowViewShortcut(IPageLayout.ID_PROP_SHEET);
		layout.addShowViewShortcut(IPageLayout.ID_PROBLEM_VIEW);
		layout.addShowViewShortcut("org.eclipse.pde.runtime.LogView");
	}

	/**
	 * Defines the initial perspective layout.
	 * 
	 * @param layout
	 *            The layout we are filling
	 */
	private void defineLayout(final IPageLayout layout) {

		final String editorArea = layout.getEditorArea();

		final IFolderLayout bottomRight = layout.createFolder("bottomRight",
				IPageLayout.RIGHT, (float) 0.25, editorArea);
		bottomRight.addView(IPageLayout.ID_PROP_SHEET);
		bottomRight.addView(IPageLayout.ID_PROBLEM_VIEW);
		bottomRight.addView("org.eclipse.pde.runtime.LogView");

		final IPlaceholderFolderLayout middleRightObjectNets = layout
				.createPlaceholderFolder("middleRightObjectNets",
						IPageLayout.TOP, (float) 0.80, "bottomRight");
		// : + Star is needed for the different secondaryIDs of the views
		middleRightObjectNets
				.addPlaceholder(IRonEditorConstants.objectNetViewID + ":*");

		final IPlaceholderFolderLayout topRightRules = layout
				.createPlaceholderFolder("topRightRules", IPageLayout.TOP,
						(float) 0.50, "middleRightObjectNets");
		topRightRules.addPlaceholder(IRonEditorConstants.ruleViewID + ":*");
	}
}