package roneditor.figures;

import java.util.Map;
import java.util.TreeMap;

import org.eclipse.draw2d.ConnectionAnchor;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.MouseEvent;
import org.eclipse.draw2d.MouseListener;
import org.eclipse.draw2d.MouseMotionListener;
import org.eclipse.draw2d.RectangleFigure;
import org.eclipse.draw2d.geometry.Point;

public class AbstractNodeFigure extends RectangleFigure {
	protected TreeMap<Integer, ConnectionAnchor> connectionAnchors;

	protected boolean showingMappingID;

	public AbstractNodeFigure() {
		connectionAnchors = new TreeMap<Integer, ConnectionAnchor>();
		addMouseListener(new MouseListener.Stub() {
			@Override
			public void mousePressed(MouseEvent me) {
				Mouse.getClickPosition().x = me.x;
				Mouse.getClickPosition().y = me.y;
				super.mousePressed(me);
			}
		});
		addMouseMotionListener(new MouseMotionListener.Stub() {
			@Override
			public void mouseMoved(MouseEvent me) {
				Mouse.getCurrentPosition().x = me.x;
				Mouse.getCurrentPosition().y = me.y;
				super.mouseMoved(me);
			}

			@Override
			public void mouseDragged(MouseEvent me) {
				Mouse.getCurrentPosition().x = me.x;
				Mouse.getCurrentPosition().y = me.y;
				super.mouseDragged(me);
			}
		});
	}

	public ConnectionAnchor getSourceConnectionAnchor() {
		return getClosestConnectionAnchorAt(Mouse.getClickPosition(),
				connectionAnchors);
	}

	public ConnectionAnchor getTargetConnectionAnchor() {
		return getClosestConnectionAnchorAt(Mouse.getCurrentPosition(),
				connectionAnchors);
	}

	public ConnectionAnchor getSourceConnectionAnchor(int id) {
		return connectionAnchors.get(id);
	}

	public ConnectionAnchor getTargetConnectionAnchor(int id) {
		return connectionAnchors.get(id);
	}

	protected void createConnectionAnchors(int nb, IFigure figure) {
		for (int i = 1; i <= nb; i++) {
			connectionAnchors.put(i, new NodeConnectionAnchor(figure, i));
		}
	}

	private ConnectionAnchor getClosestConnectionAnchorAt(Point mousePoint,
			Map<Integer, ConnectionAnchor> anchors) {
		int w = getBounds().width / 2;
		int h = getBounds().height / 2;
		ConnectionAnchor closestConnectionAnchor = anchors.get(0);
		double clostestDistance = closestConnectionAnchor.getLocation(
				new Point()).getDistance(
				new Point(mousePoint.x - w, mousePoint.y - h));
		for (ConnectionAnchor anchor : anchors.values()) {
			if (anchor instanceof NodeConnectionAnchor) {
				if (anchor.getLocation(null).getDistance(mousePoint) < clostestDistance) {
					closestConnectionAnchor = anchor;
					clostestDistance = closestConnectionAnchor
							.getLocation(null).getDistance(mousePoint);
				}
			}
		}
		return closestConnectionAnchor;
	}

	public void setShowingMappingID(boolean showingMappingID) {
		this.showingMappingID = showingMappingID;
	}
}
