package roneditor.model;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.IPropertySource;
import org.eclipse.ui.views.properties.PropertyDescriptor;
import org.eclipse.ui.views.properties.TextPropertyDescriptor;

import ronmodel.ObjectNet;

/**
 * Property source for objectNet.
 */
public class ObjectNetPropertySource implements IPropertySource {
	final public static int ID_NAME = 0;

	final public static int ID_X = 1;

	final public static int ID_Y = 2;

	final private static IPropertyDescriptor[] descriptors;

	static {
		final PropertyDescriptor nameProp = new TextPropertyDescriptor(Integer
				.valueOf(ID_NAME), "name");
		final PropertyDescriptor xProp = new TextPropertyDescriptor(Integer
				.valueOf(ID_X), "x");
		xProp.setValidator(NumberCellEditorValidator.instance(false));
		final PropertyDescriptor yProp = new TextPropertyDescriptor(Integer
				.valueOf(ID_Y), "y");
		yProp.setValidator(NumberCellEditorValidator.instance(false));
		descriptors = new IPropertyDescriptor[] { nameProp, xProp, yProp };
	}

	private ObjectNet objectNet;

	public ObjectNetPropertySource(final ObjectNet objectNet) {
		this.objectNet = objectNet;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
	 */
	public Object getPropertyValue(final Object id) {
		switch (((Integer) id).intValue()) {
		case ID_NAME:
			return objectNet.getName();
		case ID_X:
			return Integer.valueOf(objectNet.getX()).toString();
		case ID_Y:
			return Integer.valueOf(objectNet.getY()).toString();
		default:
			return null;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object,
	 *      java.lang.Object)
	 */
	public void setPropertyValue(final Object id, final Object value) {
		switch (((Integer) id).intValue()) {
		case ID_NAME:
			objectNet.setName((String) value);
			break;
		case ID_X:
			objectNet.setX(Integer.valueOf((String) value));
			break;
		case ID_Y:
			objectNet.setY(Integer.valueOf((String) value));
			break;
		default:
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
	 */
	public Object getEditableValue() {
		return objectNet;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
	 */
	public IPropertyDescriptor[] getPropertyDescriptors() {
		return descriptors;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
	 */
	public void resetPropertyValue(final Object propName) {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
	 */
	public boolean isPropertySet(final Object propName) {
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "ObjectNet(" + objectNet.getName() + "," + objectNet.getX()
				+ "," + objectNet.getY() + ")";
	}

}
