package roneditor.objectnetview;

import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.ui.actions.ActionFactory;

import roneditor.actions.FireAction;
import roneditor.editor.ContextMenuProviderWithActionRegistry;
import roneditor.objectnetview.actions.EditAction;
import roneditor.objectnetview.actions.FireONTransitionAction;

/**
 * This is used to populate the context menu for the Viewer in the
 * {@link ObjectNetPage}.
 * 
 * @author Tony Modica
 */
public class ObjectNetPageContextMenuProvider extends
		ContextMenuProviderWithActionRegistry {

	public ObjectNetPageContextMenuProvider(final EditPartViewer viewer,
			final ActionRegistry actionRegistry) {
		super(viewer, actionRegistry);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.ContextMenuProvider#buildContextMenu(org.eclipse.jface.action.IMenuManager)
	 */
	@Override
	public void buildContextMenu(final IMenuManager menuManager) {
		// HINT Hier wird das Kontextmen ber den im Editor registrierten
		// Actions aufgebaut
		GEFActionConstants.addStandardActionGroups(menuManager);

		// Actions in UNDO group
		String group = GEFActionConstants.GROUP_UNDO;
		appendActionToGroup(menuManager, ActionFactory.UNDO.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.REDO.getId(), group);

		// Actions in EDIT group
		group = GEFActionConstants.GROUP_EDIT;
		dynamicAppendActionToGroup(menuManager, GEFActionConstants.DIRECT_EDIT,
				group);
		appendActionToGroup(menuManager, ActionFactory.DELETE.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.COPY.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.CUT.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.PASTE.getId(), group);
		// Actions in REST group
		group = GEFActionConstants.GROUP_REST;
		appendActionToGroup(menuManager, EditAction.ID, group);
		appendActionToGroup(menuManager, FireONTransitionAction.ID, group);
		appendActionToGroup(menuManager, FireAction.ID, group);
	}
}
