package roneditor.objectnetview.commands;

import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.commands.Command;

import ronmodel.BendPoint;
import ronmodel.HLArc;
import ronmodel.ONArc;
/**
 * Allgemeine Klasse fr Einfgen, Lschen, ndern von einem BendPoint
 */
public abstract class AbstractBendpointCommand extends Command {

	protected int index;

	protected Point location;

	protected ONArc onArc;

	protected BendPoint bendPoint;

	protected Dimension d1, d2;

	protected HLArc hlArc;

	/**
	 * @return the relative Dimension to the source Node
	 */
	protected Dimension getFirstRelativeDimension() {
		return d1;
	}

	/**
	 * @return the relative Dimension to the target Node
	 */
	protected Dimension getSecondRelativeDimension() {
		return d2;
	}

	/**
	 * @return The index of the Bendpoint
	 */
	protected int getIndex() {
		return index;
	}
	/**
	 * @return The Location of the Bendpoint
	 */
	protected Point getLocation() {
		return location;
	}

	/**
	 * @return the ONArc to which the Bendpoint belongs to
	 */
	protected ONArc getONArc() {
		return onArc;
	}
	/**
	 * @see org.eclipse.gef.commands.Command#redo()
	 */
	public void redo() {
		execute();
	}

	/**
	 * @param dim1
	 *            Relative Dimension to the source Node
	 * @param dim2
	 *            Relative Dimension to the target Node
	 */
	public void setRelativeDimensions(Dimension dim1, Dimension dim2) {
		d1 = dim1;
		d2 = dim2;
	}

	/**
	 * Sets the BendpointIndex. Each Bendpoint has exactly one Index
	 * 
	 * @param i
	 */
	public void setIndex(int i) {
		index = i;
	}
	/**
	 * 
	 * @param p Point to set
	 */
	public void setLocation(Point p) {
		location = p;
	}
	
	/**
	 * @param w Arc to set
	 */
	public void setONArc(ONArc w) {
		onArc = w;
	}
	/**
	 * @return BendPoint
	 */
	public BendPoint getBendPoint() {
		return bendPoint;
	}

	public void setBendPoint(BendPoint bendPoint) {
		this.bendPoint = bendPoint;
	}

	protected HLArc getHLArc() {
		return hlArc;
	}

	public void setHLArc(HLArc w) {
		hlArc = w;
	}

}
