package roneditor.objectnetview.commands;

import org.eclipse.gef.commands.Command;

import roneditor.objectnetview.model.ObjectNetModelUtil;
import ronmodel.ONArc;
import ronmodel.ONNode;
import ronmodel.ONPlace;
import ronmodel.ONTransition;
import ronmodel.ObjectNet;

/**
 * Command class for a ONArc-Connection. Connects a ONNode with a other ONNode
 * via a onARC.
 */
public class CreateONArcCommand extends Command {
	private static final String ConnectionCommand_Label = "ONArc";

	private static final String ConnectionCommand_Description = "ONArc: ONNode connection command";

	protected ONNode source;

	protected ONNode target;

	protected ONArc onArc;

	protected int weight;

	protected int sourceAnchorID;

	protected int targetAnchorID;

	/**
	 * Constructor.
	 */
	public CreateONArcCommand() {
		super(ConnectionCommand_Label);
		setLabel("create Arc");
	}

	/**
	 * @return true wenn source und target unterschiedliche Klassen 
	 * haben( {@link ONPlace} -> {@link ONTransition} oder {@link ONTransition} -> {@link ONPlace}).
	 * false sonst
	 */
	public boolean canExecute() {
		if (source == null || target == null || onArc == null
				|| source.getClass() == target.getClass())
			return false;
		return ObjectNetModelUtil.getONArc(source, target) == null;
	}

	/**
	 * Entry point for the command execution.
	 * ein {@link ONArc} wird im {@link ObjectNet} zwischen 
	 * ein {@link ONPlace} und {@link ONTransition} eingefgt
	 */
	public void execute() {
		ObjectNet objectNet = target.getObjectNet();
		onArc.setSource(source);
		onArc.setTarget(target);
		onArc.setWeight(weight);
		onArc.setObjectNet(objectNet);
		onArc.setSourceAnchorID(sourceAnchorID);
		onArc.setTargetAnchorID(targetAnchorID);
	}

	/**
	 * Returns the command label.
	 */
	public String getLabel() {
		return ConnectionCommand_Description;
	}

	/**
	 * Redo command execution.
	 */
	public void redo() {
		execute();
	}

	/**
	 * Undo command execution.
	 */
	public void undo() {
		onArc.setSource(null);
		onArc.setTarget(null);
		onArc.setObjectNet(null);
	}

	public void setONArc(ONArc onArc) {
		this.onArc = onArc;
	}

	public void setSource(ONNode source) {
		this.source = source;
	}

	public void setTarget(ONNode target) {
		this.target = target;
	}

	public void setWeight(int weight) {
		this.weight = weight;
	}

	/**
	 * @return the onArc
	 */
	public ONArc getONArc() {
		return onArc;
	}

	/**
	 * @return the source
	 */
	public ONNode getSource() {
		return source;
	}

	/**
	 * @return the target
	 */
	public ONNode getTarget() {
		return target;
	}

	/**
	 * @return the weight
	 */
	public int getWeight() {
		return weight;
	}

	public int getSourceAnchorID() {
		return sourceAnchorID;
	}

	public void setSourceAnchorID(int sourceAnchorID) {
		this.sourceAnchorID = sourceAnchorID;
	}

	public int getTargetAnchorID() {
		return targetAnchorID;
	}

	public void setTargetAnchorID(int targetAnchorID) {
		this.targetAnchorID = targetAnchorID;
	}
}
