package roneditor.objectnetview.commands;

import org.eclipse.gef.commands.Command;

import ronmodel.ONArc;
import ronmodel.ONPlace;
import ronmodel.ONTransition;
/**
 * command zum feuern eines {@link ONTransition}
 */
public class FireONTransitionCommand extends Command {
	private ONTransition onTransition;

	public FireONTransitionCommand() {
		setLabel("fire transition");
	}

	/**
	 * Von jeder Vorbereichsstelle dieser Transition wird soviel Tokens entfernt 
	 * wie der Gewicht der zugehrige Eingangskante und in jeder Nachbereichstelle 
	 * wird soviel tokens eingefgt wie der Gewicht der zugehrige Ausgangskante
	 * @see org.eclipse.gef.commands.Command#execute()
	 */
	public void execute() {
		ONArc inputArc = null;
		ONPlace source = null;
		for (Object input : onTransition.getIncoming()) {
			inputArc = (ONArc) input;
			source = (ONPlace) inputArc.getSource();
			source.setTokens(source.getTokens() - inputArc.getWeight());
		}
		ONArc outputArc = null;
		ONPlace target = null;
		for (Object output : onTransition.getOutgoing()) {
			outputArc = (ONArc) output;
			target = (ONPlace) outputArc.getTarget();
			target.setTokens(target.getTokens() + outputArc.getWeight());
		}
	}

	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo() {
		ONArc outputArc = null;
		ONPlace target = null;
		for (Object output : onTransition.getOutgoing()) {
			outputArc = (ONArc) output;
			target = (ONPlace) outputArc.getTarget();
			target.setTokens(target.getTokens() - outputArc.getWeight());
		}
		ONArc inputArc = null;
		ONPlace source = null;
		for (Object input : onTransition.getIncoming()) {
			inputArc = (ONArc) input;
			source = (ONPlace) inputArc.getSource();
			source.setTokens(source.getTokens() + inputArc.getWeight());
		}
	}

	/**
	 * @see org.eclipse.gef.commands.Command#redo()
	 */
	public void redo() {
		execute();
	}

	/**
	 * @return true wenn in jeder Vorbereichsstelle dieser Transition 
	 * mindestens soviel Tokens gibt als die Gewicht der zugehrige Kante 
	 */
	public boolean canExecute() {
		ONArc inputArc = null;
		ONPlace source = null;
		for (Object input : onTransition.getIncoming()) {
			inputArc = (ONArc) input;
			source = (ONPlace) inputArc.getSource();
			if (source.getTokens() < inputArc.getWeight()) {
				return false;
			}
		}
		return true;
	}

	public ONTransition getOnTransition() {
		return onTransition;
	}

	public void setOnTransition(ONTransition onTransition) {
		this.onTransition = onTransition;
	}
}
