package roneditor.objectnetview.commands;

import org.eclipse.gef.commands.Command;

import roneditor.objectnetview.model.ObjectNetModelUtil;
import ronmodel.ONArc;
import ronmodel.ONNode;
import ronmodel.ObjectNet;
/**
 * command fr ndern des sources eines {@link ONArc}
 */
public class ReconnectONSourceCommand extends Command {
	protected ONNode oldSource;

	protected ONNode newSource;

	protected ONArc onArc;

	public ReconnectONSourceCommand() {
		setLabel("reconnect source");
	}

	/**
	 * @return <code>true</code> wenn die neue Source und alte Target aus 
	 * unterschiedliche Klassen sind und keine {@link ONArc} haben
	 */
	public boolean canExecute() {
		if (newSource == onArc.getSource())
			return true;
		if (newSource == null || onArc == null
				|| newSource.getClass() == onArc.getTarget().getClass())
			return false;
		return ObjectNetModelUtil.getONArc(newSource, onArc.getTarget()) == null;
	}

	/**
	 * Entry point for the command execution.
	 * altes Source wird durch die neue Source ersetzt.
	 */
	public void execute() {
		ONNode target = onArc.getTarget();
		ObjectNet objectNet = onArc.getObjectNet();
		oldSource = onArc.getSource();

		onArc.setSource(null);
		onArc.setTarget(null);
		onArc.setObjectNet(null);

		onArc.setSource(newSource);
		onArc.setTarget(target);
		onArc.setObjectNet(objectNet);
	}

	/**
	 * Redo command execution.
	 */
	public void redo() {
		execute();
	}

	/**
	 * Undo command execution.
	 */
	public void undo() {
		ONNode target = onArc.getTarget();
		ObjectNet objectNet = onArc.getObjectNet();

		onArc.setSource(null);
		onArc.setTarget(null);
		onArc.setObjectNet(null);

		onArc.setSource(oldSource);
		onArc.setTarget(target);
		onArc.setObjectNet(objectNet);
	}

	public ONNode getNewSource() {
		return newSource;
	}

	public void setNewSource(ONNode newSource) {
		this.newSource = newSource;
	}

	public ONArc getONArc() {
		return onArc;
	}

	public void setONArc(ONArc onArc) {
		this.onArc = onArc;
	}
}
