package roneditor.objectnetview.commands;

import org.eclipse.gef.commands.Command;

import roneditor.objectnetview.model.ObjectNetModelUtil;
import ronmodel.ONArc;
import ronmodel.ONNode;
import ronmodel.ObjectNet;
/**
 * command fr ndern des Targets eines {@link ONArc}
 */
public class ReconnectONTargetCommand extends Command {
	protected ONNode oldTarget;

	protected ONNode newTarget;

	protected ONArc onArc;

	public ReconnectONTargetCommand() {
		setLabel("reconnect target");
	}

	/**
	 * @return <code>true</code> wenn die neue Target und alte Source aus 
	 * unterschiedliche Klassen sind und keine {@link ONArc} haben.
	 */
	public boolean canExecute() {
		if (newTarget == onArc.getTarget())
			return true;
		if (newTarget == null || onArc == null
				|| newTarget.getClass() == onArc.getSource().getClass())
			return false;
		return ObjectNetModelUtil.getONArc(onArc.getSource(), newTarget) == null;
	}

	/**
	 * Entry point for the command execution.
	 * altes Target wird durch die neue Target ersetzt.
	 */
	public void execute() {
		ONNode source = onArc.getSource();
		ObjectNet objectNet = onArc.getObjectNet();
		oldTarget = onArc.getTarget();

		onArc.setSource(null);
		onArc.setTarget(null);
		onArc.setObjectNet(null);

		onArc.setSource(source);
		onArc.setTarget(newTarget);
		onArc.setObjectNet(objectNet);
	}

	/**
	 * Redo command execution.
	 */
	public void redo() {
		execute();
	}

	/**
	 * Undo command execution.
	 */
	public void undo() {
		ONNode source = onArc.getSource();
		ObjectNet objectNet = onArc.getObjectNet();

		onArc.setSource(null);
		onArc.setTarget(null);
		onArc.setObjectNet(null);

		onArc.setSource(source);
		onArc.setTarget(oldTarget);
		onArc.setObjectNet(objectNet);
	}

	public ONNode getNewTarget() {
		return newTarget;
	}

	public void setNewTarget(ONNode newTarget) {
		this.newTarget = newTarget;
	}

	public ONArc getONArc() {
		return onArc;
	}

	public void setONArc(ONArc onArc) {
		this.onArc = onArc;
	}
}
