package roneditor.objectnetview.edit.parts;

import org.eclipse.draw2d.ConnectionAnchor;
import org.eclipse.gef.ConnectionEditPart;
import org.eclipse.gef.Request;
import org.eclipse.gef.editparts.AbstractGraphicalEditPart;

import roneditor.figures.AbstractNodeFigure;
import roneditor.figures.NodeConnectionAnchor;
import ronmodel.ONArc;
import ronmodel.ONNode;
/**
 * Editpart for a {@link ONNode}
 */
public abstract class AbstractONNodeEditPart extends AbstractGraphicalEditPart {
	protected int anchorID = -1;

	public int getAnchorID() {
		return anchorID;
	}
	/**
	 * 
	 * @return {@link AbstractNodeFigure} fr dieses Editpart
	 */
	public AbstractNodeFigure getONNodeFigure() {
		return (AbstractNodeFigure) getFigure();
	}

	/**
	 * @see org.eclipse.gef.NodeEditPart#getSourceConnectionAnchor(org.eclipse.gef.ConnectionEditPart)
	 */
	public ConnectionAnchor getSourceConnectionAnchor(
			ConnectionEditPart connection) {
		if (anchorID != -1) {
			return getONNodeFigure().getTargetConnectionAnchor(anchorID);
		} else {
			if (connection instanceof ONArcEditPart) {
				ONArc onArc = ((ONArcEditPart) connection).getONArc();
				return getONNodeFigure().getTargetConnectionAnchor(
						onArc.getTargetAnchorID());
			} else {
				return getONNodeFigure().getTargetConnectionAnchor(0);
			}
		}
	}

	/**
	 * @see org.eclipse.gef.NodeEditPart#getSourceConnectionAnchor(org.eclipse.gef.Request)
	 */
	public ConnectionAnchor getSourceConnectionAnchor(Request request) {
		if (getONNodeFigure().getSourceConnectionAnchor() instanceof NodeConnectionAnchor) {
			NodeConnectionAnchor onNodeConnectionAnchor = (NodeConnectionAnchor) getONNodeFigure()
					.getSourceConnectionAnchor();
			anchorID = onNodeConnectionAnchor.getId();
		} else {
			anchorID = 0;
		}
		return getONNodeFigure().getSourceConnectionAnchor();
	}

	/**
	 * @see org.eclipse.gef.NodeEditPart#getTargetConnectionAnchor(org.eclipse.gef.ConnectionEditPart)
	 */
	public ConnectionAnchor getTargetConnectionAnchor(
			ConnectionEditPart connection) {
		if (anchorID != -1) {
			return getONNodeFigure().getSourceConnectionAnchor(anchorID);
		} else {
			if (connection instanceof ONArcEditPart) {
				ONArc onArc = ((ONArcEditPart) connection).getONArc();
				return getONNodeFigure().getSourceConnectionAnchor(
						onArc.getSourceAnchorID());
			} else {
				return getONNodeFigure().getSourceConnectionAnchor(0);
			}
		}

	}

	/**
	 * @see org.eclipse.gef.NodeEditPart#getTargetConnectionAnchor(org.eclipse.gef.Request)
	 */
	public ConnectionAnchor getTargetConnectionAnchor(Request request) {
		if (getONNodeFigure().getTargetConnectionAnchor() instanceof NodeConnectionAnchor) {
			NodeConnectionAnchor onNodeConnectionAnchor = (NodeConnectionAnchor) getONNodeFigure()
					.getTargetConnectionAnchor();
			anchorID = onNodeConnectionAnchor.getId();
		} else {
			anchorID = 0;
		}
		return getONNodeFigure().getTargetConnectionAnchor();
	}
}
