package roneditor.objectnetview.edit.policies;

import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.GraphicalEditPart;
import org.eclipse.gef.Request;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.editpolicies.NonResizableEditPolicy;
import org.eclipse.gef.editpolicies.XYLayoutEditPolicy;
import org.eclipse.gef.requests.CreateRequest;

import roneditor.objectnetview.commands.CreateONPlaceCommand;
import roneditor.objectnetview.commands.CreateONTransitionCommand;
import roneditor.objectnetview.commands.SetConstraintCommand;
import ronmodel.ONNode;
import ronmodel.ONPlace;
import ronmodel.ONTransition;
import ronmodel.ObjectNet;

/**
 * EditPolicy for XY-Layout.
 */
public class ObjectNetXYLayoutEditPolicy extends XYLayoutEditPolicy {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.editpolicies.ConstrainedLayoutEditPolicy#createAddCommand(org.eclipse.gef.EditPart,
	 *      java.lang.Object)
	 */
	protected Command createAddCommand(EditPart child, Object constraint) {
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.editpolicies.LayoutEditPolicy#getCreateCommand(org.eclipse.gef.requests.CreateRequest)
	 */
	protected Command getCreateCommand(CreateRequest request) {
		Object newObjectType = request.getNewObjectType();
		Command createCommand = null;

		if (newObjectType == ONPlace.class) {
			CreateONPlaceCommand create = new CreateONPlaceCommand();
			create.setONPlace((ONPlace) request.getNewObject());
			create.setObjectNet((ObjectNet) getHost().getModel());
			create.setX(request.getLocation().x);
			create.setY(request.getLocation().y);
			create.setLabel("create a ONPlace");
			createCommand = create;
		} else if (newObjectType == ONTransition.class) {
			CreateONTransitionCommand create = new CreateONTransitionCommand();
			create.setServer((ONTransition) request.getNewObject());
			create.setObjectNet((ObjectNet) getHost().getModel());
			create.setX(request.getLocation().x);
			create.setY(request.getLocation().y);
			create.setLabel("create a ONTransition");
			createCommand = create;
		}

		return createCommand;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.editpolicies.LayoutEditPolicy#getDeleteDependantCommand(org.eclipse.gef.Request)
	 */
	protected Command getDeleteDependantCommand(Request request) {
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.editpolicies.LayoutEditPolicy#createChildEditPolicy(org.eclipse.gef.EditPart)
	 */
	protected EditPolicy createChildEditPolicy(EditPart child) {
		return new NonResizableEditPolicy();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.editpolicies.XYLayoutEditPolicy#getMinimumSizeFor(org.eclipse.gef.GraphicalEditPart)
	 */
	protected Dimension getMinimumSizeFor(GraphicalEditPart child) {
		return child.getContentPane().getMinimumSize();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.editpolicies.ConstrainedLayoutEditPolicy#createChangeConstraintCommand(org.eclipse.gef.EditPart,
	 *      java.lang.Object)
	 */
	protected Command createChangeConstraintCommand(EditPart child,
			Object constraint) {
		SetConstraintCommand locationCommand = new SetConstraintCommand();
		locationCommand.setONNode((ONNode) child.getModel());
		locationCommand.setNewPosition(((Rectangle) constraint).getLocation());
		return locationCommand;
	}

}
