package roneditor.objectnetview.figures;

import org.eclipse.draw2d.ChopboxAnchor;
import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.Label;
import org.eclipse.draw2d.XYLayout;
import org.eclipse.draw2d.geometry.Dimension;
import org.eclipse.draw2d.geometry.Rectangle;

import roneditor.figures.AbstractNodeFigure;
import roneditor.figures.NodeConnectionAnchor;
import ronmodel.ONTransition;
/**
 * Represents the graphical layout of a {@link ONTransition}.
 */
public class ONTransitionFigure extends AbstractNodeFigure {
	public static final int NUMBER_OF_ANCHORS = 12;

	protected Label label;

	protected XYLayout layout;

	public ONTransitionFigure() {
		super();
		layout = new XYLayout();
		setLayoutManager(layout);
		setBackgroundColor(ColorConstants.white);
		setOpaque(false);
		// createConnectionAnchors(NUMBER_OF_ANCHORS,this);
		connectionAnchors.put(0, new ChopboxAnchor(this));
		label = new Label(" ");
		add(label);
		setBackgroundColor(ColorConstants.lightGreen);
	}

	public void setName(String name) {
		if (name != null) {
			label.setText(name);
		} else {
			label.setText(" ");
		}

		validate();
	}

	public void setMappingID(int mappingID) {
		if (mappingID > 0 && showingMappingID) {
			label.setText(mappingID + ": " + label.getText());
			validate();
		}
	}

	public void validate() {
		layout.setConstraint(label, new Rectangle(5, 5, -1, -1));
		// refreshConnectionAnchors();
		super.validate();
	}

	protected boolean useLocalCoordinates() {
		return true;
	}

	public Dimension getMinimumSize(int wHint, int hHint) {
		return getPreferredSize();
	}

	public Dimension getPreferredSize(int wHint, int hHint) {
		int diam = Math.max(label.getSize().width, label.getSize().height) + 10;
		return new Dimension(diam, 22);
	}

	private void refreshConnectionAnchors() {
		NodeConnectionAnchor anchor = null;
		int w = getBounds().width / 4;
		int h = getBounds().height / 2;
		for (int i = 1; i < 6; i++) {
			anchor = (NodeConnectionAnchor) connectionAnchors.get(i);
			anchor.setOffsetH((i - 1) * w);
			anchor.setOffsetV(0);
		}
		anchor = (NodeConnectionAnchor) connectionAnchors.get(6);
		anchor.setOffsetH(getBounds().width - 1);
		anchor.setOffsetV(h);
		for (int i = 7; i < 12; i++) {
			anchor = (NodeConnectionAnchor) connectionAnchors.get(i);
			anchor.setOffsetH((11 - i) * w);
			anchor.setOffsetV(getBounds().height - 1);
		}
		anchor = (NodeConnectionAnchor) connectionAnchors.get(12);
		anchor.setOffsetH(0);
		anchor.setOffsetV(h);
	}
}
