package roneditor.objectnetview.model;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.IPropertySource;
import org.eclipse.ui.views.properties.PropertyDescriptor;

import roneditor.model.NumberCellEditorValidator;
import ronmodel.ONTransition;

/**
 * Property source for onTransition.
 */
public class ONTransitionPropertySource implements IPropertySource {
	final public static int ID_NAME = 0;

	final public static int ID_X = 1;

	final public static int ID_Y = 2;

	final private static IPropertyDescriptor[] descriptors;

	static {
		final PropertyDescriptor nameProp = new PropertyDescriptor(Integer
				.valueOf(ID_NAME), "name");
		final PropertyDescriptor xProp = new PropertyDescriptor(Integer
				.valueOf(ID_X), "x");
		xProp.setValidator(NumberCellEditorValidator.instance(false));
		final PropertyDescriptor yProp = new PropertyDescriptor(Integer
				.valueOf(ID_Y), "y");
		yProp.setValidator(NumberCellEditorValidator.instance(false));
		descriptors = new IPropertyDescriptor[] { nameProp, xProp, yProp };
	}

	private ONTransition onTransition;

	public ONTransitionPropertySource(final ONTransition onTransition) {
		this.onTransition = onTransition;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
	 */
	public Object getPropertyValue(final Object id) {
		switch (((Integer) id).intValue()) {
		case ID_NAME:
			return onTransition.getName();
		case ID_X:
			return Integer.valueOf(onTransition.getX()).toString();
		case ID_Y:
			return Integer.valueOf(onTransition.getY()).toString();
		default:
			return null;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object,
	 *      java.lang.Object)
	 */
	public void setPropertyValue(final Object id, final Object value) {
		switch (((Integer) id).intValue()) {
		case ID_NAME:
			onTransition.setName((String) value);
			break;
		case ID_X:
			onTransition.setX(Integer.valueOf((String) value));
			break;
		case ID_Y:
			onTransition.setY(Integer.valueOf((String) value));
			break;
		default:
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
	 */
	public Object getEditableValue() {
		return onTransition;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
	 */
	public IPropertyDescriptor[] getPropertyDescriptors() {
		return descriptors;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
	 */
	public void resetPropertyValue(final Object propName) {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
	 */
	public boolean isPropertySet(final Object propName) {
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "ONTransition(" + onTransition.getName() + ","
				+ onTransition.getX() + "," + onTransition.getY() + ")";
	}

}
