package roneditor.objectnetview.model;

import java.util.Vector;

import org.eclipse.emf.common.util.EList;

import ronmodel.ONArc;
import ronmodel.ONNode;
import ronmodel.ONPlace;
import ronmodel.ONTransition;
import ronmodel.ObjectNet;
/**
 * in dieser Klasse werden hilfsmethoden implementiert, die auf {@link ObjectNet Modell}
 * zugreifen. diese Methoden werden am meistens in den Commands benutzt
 */
public class ObjectNetModelUtil {
	/**
	 * 
	 * @param source 
	 * @param target
	 * @return {@link ONArc onArc} zwischen {@link ONNode source} und {@link ONNode target}
	 * wenn es existiert, null sonst
	 */
	public static ONArc getONArc(ONNode source, ONNode target) {
		EList outgoing = source.getOutgoing();
		ONArc onArc = null;
		for (Object object : outgoing) {
			onArc = (ONArc) object;
			if (onArc.getTarget() == target)
				return onArc;
		}
		return null;
	}

	/**
	 * 
	 * @param onTransition
	 * @return true wenn die {@link ONTransition onTransition} aktiv(Kann feuern) ist, 
	 * false sonst 
	 */
	public static boolean isActive(ONTransition onTransition) {
		ONArc inputArc = null;
		ONPlace source = null;
		for (Object input : onTransition.getIncoming()) {
			inputArc = (ONArc) input;
			source = (ONPlace) inputArc.getSource();
			if (source != null && source.getTokens() < inputArc.getWeight()) {
				return false;
			}
		}
		return true;
	}

	/**
	 * 
	 * @param objectNet
	 * @return alle aktive {@link ONTransition onTransitions} in einem {@link ObjectNet objectNet}
	 */
	public static Vector<ONTransition> getActiveONTransitions(
			ObjectNet objectNet) {
		Vector<ONTransition> activeTransitions = new Vector<ONTransition>();
		for (Object o : objectNet.getNodes()) {
			if (o instanceof ONTransition) {
				ONTransition transition = (ONTransition) o;
				if (isActive(transition)) {
					activeTransitions.add(transition);
				}
			}
		}
		return activeTransitions;
	}
	/**
	 * Hier wird die Name alle {@link ONNode onNodes} in einem {@link ObjectNet },
	 * die keinen Namen haben, gesetzt
	 * @param objectNet
	 * 
	 */
	public static void setNameForEmptyNodes(ObjectNet objectNet) {
		int transitionCounter = 0;
		int placeCounter = 0;
		for (Object o : objectNet.getNodes()) {
			ONNode node = (ONNode) o;
			if (node.getName() == null || node.getName().equalsIgnoreCase("")) {
				if (o instanceof ONPlace) {
					node.setName("newPlace" + (++placeCounter));
				} else if (o instanceof ONTransition) {
					node.setName("newTransition" + (++transitionCounter));
				}
			}
		}
	}
}
