package roneditor.ronview;

import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.ui.actions.ActionFactory;

import roneditor.actions.ApplyRuleAction;
import roneditor.actions.CreateTokenAction;
import roneditor.editor.ContextMenuProviderWithActionRegistry;
import roneditor.ronview.actions.FireHLTransitionAction;

/**
 * This is used to populate the context menu for the Viewer in the
 * {@link RONPage}.
 * 
 * @author Tony Modica
 */
public class RONPageContextMenuProvider extends
		ContextMenuProviderWithActionRegistry {

	public RONPageContextMenuProvider(final EditPartViewer viewer,
			final ActionRegistry actionRegistry) {
		super(viewer, actionRegistry);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.ContextMenuProvider#buildContextMenu(org.eclipse.jface.action.IMenuManager)
	 */
	@Override
	public void buildContextMenu(final IMenuManager menuManager) {
		// HINT Hier wird das Kontextmen ber den im Editor registrierten
		// Actions aufgebaut
		GEFActionConstants.addStandardActionGroups(menuManager);

		// Actions in UNDO group
		String group = GEFActionConstants.GROUP_UNDO;
		appendActionToGroup(menuManager, ActionFactory.UNDO.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.REDO.getId(), group);

		// Actions in EDIT group
		group = GEFActionConstants.GROUP_EDIT;
		dynamicAppendActionToGroup(menuManager, GEFActionConstants.DIRECT_EDIT,
				group);
		appendActionToGroup(menuManager, ActionFactory.DELETE.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.COPY.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.CUT.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.PASTE.getId(), group);
		appendActionToGroup(menuManager, FireHLTransitionAction.ID, group);
		appendActionToGroup(menuManager, ApplyRuleAction.ID, group);
		dynamicAppendActionToGroup(menuManager, CreateTokenAction.ID, group);

		// Actions in REST group
		/*
		 * TODO:Actions ndern group = GEFActionConstants.GROUP_REST;
		 * appendActionToGroup(menuManager, EditAction.ID, group);
		 * 
		 * appendActionToGroup(menuManager, ApplyRuleAction.ID, group);
		 */
	}
}
