package roneditor.ronview.commands;

import org.eclipse.gef.commands.Command;

import roneditor.ronview.model.RONModelUtil;
import ronmodel.HLArc;
import ronmodel.HLNode;
import ronmodel.RON;

/**
 * Command class for creation a {@link HLArc}
 */
public class CreateHLArcCommand extends Command {
	private static final String ConnectionCommand_Label = "HLArc";

	private static final String ConnectionCommand_Description = "HLArc: HLNode connection command";

	protected HLNode source;

	protected HLNode target;

	protected HLArc hlArc;

	/**
	 * Constructor.
	 */
	public CreateHLArcCommand() {
		super(ConnectionCommand_Label);
		setLabel("create Arc");
	}

	/**
	 * @return true wenn source und target unterschiedliche klassen haben 
	 * und kein verbindung miteinander haben( {@link HLArc})
	 */
	public boolean canExecute() {
		if (source == null || target == null || hlArc == null
				|| source.getClass() == target.getClass())
			return false;
		return RONModelUtil.getHLArc(source, target) == null;
	}

	/**
	 * Entry point for the command execution.
	 * ein {@link HLArc} wird zwischen source und target eingefgt
	 */
	public void execute() {
		RON ron = target.getRon();
		hlArc.setSource(source);
		hlArc.setTarget(target);
		hlArc.setRon(ron);
	}

	/**
	 * Returns the command label.
	 */
	public String getLabel() {
		return ConnectionCommand_Description;
	}

	/**
	 * Redo command execution.
	 */
	public void redo() {
		execute();
	}

	/**
	 * Undo command execution.
	 */
	public void undo() {
		hlArc.setSource(null);
		hlArc.setTarget(null);
		hlArc.setRon(null);
	}

	public HLArc getHlArc() {
		return hlArc;
	}

	public void setHlArc(HLArc hlArc) {
		this.hlArc = hlArc;
	}

	public HLNode getSource() {
		return source;
	}

	public void setSource(HLNode source) {
		this.source = source;
	}

	public HLNode getTarget() {
		return target;
	}

	public void setTarget(HLNode target) {
		this.target = target;
	}

}
