package roneditor.ronview.commands;

import ronmodel.HLArc;
import ronmodel.HLNode;
import ronmodel.RON;

/**
 * Command for deleting a {@link HLArc}.
 */
public class DeleteHLArcCommand extends org.eclipse.gef.commands.Command {
	private static final String DeleteCommand_Label = "DeleteHLArcCommand";

	private HLArc hlArc;

	private HLNode source;

	private HLNode target;

	private RON ron;

	/**
	 * constructor
	 */
	public DeleteHLArcCommand() {
		super(DeleteCommand_Label);
		setLabel("delete Arc");
	}

	/**
	 * Entry point for command execution.
	 * ein existierendes {@link HLArc} zwischen 2 {@link HLNode hlNodes} 
	 * wird gelscht
	 */
	public void execute() {
		source = hlArc.getSource();
		target = hlArc.getTarget();
		ron = hlArc.getRon();
		hlArc.setSource(null);
		hlArc.setTarget(null);
		hlArc.setRon(null);
	}

	public void redo() {
		execute();
	}

	/**
	 * Undo command execution.
	 */
	public void undo() {
		hlArc.setSource(source);
		hlArc.setTarget(target);
		hlArc.setRon(ron);
	}

	@Override
	public boolean canExecute() {
		return hlArc != null && hlArc.getSource() != null
				&& hlArc.getTarget() != null && hlArc.getRon() != null;
	}

	public HLArc getHlArc() {
		return hlArc;
	}

	public void setHlArc(HLArc hlArc) {
		this.hlArc = hlArc;
	}

	public RON getRon() {
		return ron;
	}

	public void setRon(RON ron) {
		this.ron = ron;
	}

	public HLNode getSource() {
		return source;
	}

	public void setSource(HLNode source) {
		this.source = source;
	}

	public HLNode getTarget() {
		return target;
	}

	public void setTarget(HLNode target) {
		this.target = target;
	}

}
