package roneditor.ronview.commands;

import org.eclipse.gef.commands.Command;

import ronmodel.HLPlace;
import ronmodel.Token;

/**
 * Command for removing a token from its parent place. This is undoable.
 */
public class DeleteTokenCommand extends Command {

	private static final String DeleteCommand_Label = "Delete token";

	final private Token token;

	private HLPlace parent;

	public DeleteTokenCommand(final Token token) {
		super(DeleteTokenCommand.DeleteCommand_Label);
		this.token = token;
	}

	/**
	 * The child gets removed from its parent. The container is stored for
	 * undoing purposes.
	 * @see org.eclipse.gef.commands.Command#execute()
	 */
	@Override
	public void execute() {
		parent = token.getPlace();
		token.setPlace(null);
	}

	/**
	 * Undoes the command by readding the previously removed object to its
	 * former container that {@link #execute()} has saved. (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	@Override
	public void undo() {
		token.setPlace(parent);
	}

	/**
	 * Redoes the command by removing the object from its container again.
	 */
	@Override
	public void redo() {
		token.setPlace(null);
	}
}
