package roneditor.ronview.commands;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.gef.commands.Command;

import roneditor.converter.RuleSimulator;
import roneditor.objectnetview.model.ObjectNetModelUtil;
import roneditor.ronview.model.RONModelUtil;
import ronmodel.HLPlace;
import ronmodel.HLTransition;
import ronmodel.ONNode;
import ronmodel.ObjectNet;
import ronmodel.Rule;
import ronmodel.Token;
/**
 * Class zum feuern ein {@link HLTransition ApplyRule-HLTransition}
 */
public class FireApplyRuleHLTransitionCommand extends Command {
	private HLTransition transition;

	private Map<Token, HLPlace> sourceTokens = new HashMap<Token, HLPlace>();

	private Map<Token, HLPlace> targetTokens = new HashMap<Token, HLPlace>();

	private ObjectNet unionObjectNet;
	
	private Rule sourceRule;
	
	private Rule sourceRuleNoEmptyNac;
	
	private HashMap<ONNode, ONNode> matchToApply;
	 
	public FireApplyRuleHLTransitionCommand() {
		setLabel("fire transition");
	}

	/**
	 * auf das Union alle selektierten {@link ObjectNet objectNets} im Vorbereich wird das 
	 * selektiete {@link Rule regel} angewendet. alle selektierten elementen im Vorbereich werden 
	 * entfernt und das ergebnis wird in Alle NetPlaces im Nachbereich eingefgt 
	 * und die selektierte Regel wird in alle RulePlaces im Nachbereich eingefgt 
	 * @see org.eclipse.gef.commands.Command#execute()
	 */
	public void execute() {
		new RuleSimulator().applyRule(matchToApply,sourceRuleNoEmptyNac,unionObjectNet);
		ObjectNetModelUtil.setNameForEmptyNodes(unionObjectNet);
		
		for (Token token : sourceTokens.keySet()) {
			token.setPlace(null);
		}
		Collection<HLPlace> targetNetPlaces = RONModelUtil
				.getTargetNetPlaces(transition);
		Collection<HLPlace> targetRulePlaces = RONModelUtil
				.getTargetRulePlaces(transition);

		for (HLPlace place : targetNetPlaces) {
			unionObjectNet.setPlace(place);
			unionObjectNet.setSelected(true);
			targetTokens.put(unionObjectNet, place);
			unionObjectNet = (ObjectNet) EcoreUtil.copy(unionObjectNet);
		}

		Rule copyOfSourceRule = (Rule) EcoreUtil.copy(sourceRule);
		for (HLPlace place : targetRulePlaces) {
			copyOfSourceRule.setPlace(place);
			copyOfSourceRule.setSelected(true);
			targetTokens.put(copyOfSourceRule, place);
			copyOfSourceRule = (Rule) EcoreUtil.copy(copyOfSourceRule);
		}
	}

	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo() {
		HLPlace place = null;
		for (Token token : sourceTokens.keySet()) {
			place = sourceTokens.get(token);
			token.setPlace(place);
		}
		for (Token token : targetTokens.keySet()) {
			token.setPlace(null);
		}
	}

	/**
	 * @see org.eclipse.gef.commands.Command#redo()
	 */
	public void redo() {
		HLPlace place = null;
		for (Token token : sourceTokens.keySet()) {
			token.setPlace(null);
		}
		for (Token token : targetTokens.keySet()) {
			place = targetTokens.get(token);
			token.setPlace(place);
		}
	}

	/**
	 * True if the command can be executed, false otherwise.
	 */
	public boolean canExecute() {
		return true;
	}

	public void setTransition(HLTransition transition) {
		this.transition = transition;
	}

	public Map<Token, HLPlace> getSourceTokens() {
		return sourceTokens;
	}

	public Map<Token, HLPlace> getTargetTokens() {
		return targetTokens;
	}

	public void setUnionObjectNet(ObjectNet unionObjectNet) {
		this.unionObjectNet = unionObjectNet;
	}

	public void setSourceRule(Rule sourceRule) {
		this.sourceRule = sourceRule;
	}

	public void setMatchToApply(HashMap<ONNode, ONNode> matchToApply) {
		this.matchToApply = matchToApply;
	}

	public void setSourceRuleNoEmptyNac(Rule sourceRuleNoEmptyNac) {
		this.sourceRuleNoEmptyNac = sourceRuleNoEmptyNac;
	}
}
