package roneditor.ronview.commands;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.gef.commands.Command;

import roneditor.objectnetview.commands.FireONTransitionCommand;
import roneditor.ronview.model.RONModelUtil;
import ronmodel.HLPlace;
import ronmodel.HLTransition;
import ronmodel.ONTransition;
import ronmodel.ObjectNet;
/**
 * command zum feuern ein {@link HLTransition fireTransition}
 */
public class FireFireHLTransitionCommand extends Command {
	private HLTransition hlTransition;

	private ONTransition onTransition;

	private ObjectNet sourceObjectNet = null;

	private ObjectNet copyOfSourceObjectNet = null;

	private HLPlace sourcePlace = null;

	private Map<ObjectNet, HLPlace> targetObjectNets = new HashMap<ObjectNet, HLPlace>();

	public FireFireHLTransitionCommand() {
		setLabel("fire transition");
	}

	/**
	 * ein selektierte {@link ONTransition} in einem Selektierten 
	 * {@link ObjectNet} in einem Vorbereichstelle eines {@link HLTransition} wird 
	 * gefeuert.das resultierende {@link ObjectNet} wird in allen Nachbereichstellen 
	 * kopiert und das ursprungliche wird gelscht 
	 */
	public void execute() {
		Collection<HLPlace> sourceNetPlaces = RONModelUtil
				.getSourceNetPlaces(hlTransition);
		sourcePlace = sourceNetPlaces.iterator().next();
		FireONTransitionCommand fireONTransitionCommand = new FireONTransitionCommand();
		fireONTransitionCommand.setOnTransition(onTransition);
		fireONTransitionCommand.execute();
		Collection<HLPlace> targetNetPlaces = RONModelUtil
				.getTargetNetPlaces(hlTransition);

		// Execute
		sourceObjectNet.setPlace(null);
		for (HLPlace place : targetNetPlaces) {
			targetObjectNets.put(copyOfSourceObjectNet, place);
			copyOfSourceObjectNet.setPlace(place);
			copyOfSourceObjectNet = (ObjectNet) EcoreUtil
					.copy(copyOfSourceObjectNet);
		}
	}

	/**
	 * @see org.eclipse.gef.commands.Command#undo()
	 */
	public void undo() {

		for (ObjectNet net : targetObjectNets.keySet()) {
			net.setPlace(null);
		}
		sourceObjectNet.setPlace(sourcePlace);
	}

	/**
	 * @see org.eclipse.gef.commands.Command#redo()
	 */
	public void redo() {
		sourceObjectNet.setPlace(null);
		for (ObjectNet net : targetObjectNets.keySet()) {
			net.setPlace(targetObjectNets.get(net));
		}

	}

	/**
	 * True if the command can be executed, false otherwise.
	 */
	public boolean canExecute() {
		return true;
	}

	public void setHLTransition(HLTransition transition) {
		this.hlTransition = transition;
	}

	public void setONTransition(ONTransition transition) {
		this.onTransition = transition;
	}

	public void setSourceObjectNet(ObjectNet sourceObjectNet) {
		this.sourceObjectNet = sourceObjectNet;
	}

	public void setCopyOfSourceObjectNet(ObjectNet copyOfSourceObjectNet) {
		this.copyOfSourceObjectNet = copyOfSourceObjectNet;
	}
}
