package roneditor.ronview.commands;

import org.eclipse.gef.commands.Command;

import roneditor.ronview.model.RONModelUtil;
import ronmodel.HLArc;
import ronmodel.HLNode;
import ronmodel.RON;
/**
 * commad zum ndern des {@link HLNode target} eines {@link HLArc}
 */
public class ReconnectHLTargetCommand extends Command {
	protected HLNode oldTarget;

	protected HLNode newTarget;

	protected HLArc hlArc;

	public ReconnectHLTargetCommand() {
		setLabel("reconnect target");
	}

	/**
	 * True if the command can be executed, false otherwise.
	 */
	public boolean canExecute() {
		if (newTarget == hlArc.getTarget())
			return true;
		if (newTarget == null || hlArc == null
				|| newTarget.getClass() == hlArc.getSource().getClass())
			return false;
		return RONModelUtil.getHLArc(hlArc.getSource(), newTarget) == null;
	}

	/**
	 * Entry point for the command execution.
	 */
	public void execute() {
		HLNode source = hlArc.getSource();
		RON ron = hlArc.getRon();
		oldTarget = hlArc.getTarget();

		hlArc.setSource(null);
		hlArc.setTarget(null);
		hlArc.setRon(null);

		hlArc.setSource(source);
		hlArc.setTarget(newTarget);
		hlArc.setRon(ron);
	}

	/**
	 * Redo command execution.
	 */
	public void redo() {
		execute();
	}

	/**
	 * Undo command execution.
	 */
	public void undo() {
		HLNode source = hlArc.getSource();
		RON ron = hlArc.getRon();

		hlArc.setSource(null);
		hlArc.setTarget(null);
		hlArc.setRon(null);

		hlArc.setSource(source);
		hlArc.setTarget(oldTarget);
		hlArc.setRon(ron);
	}

	public HLNode getNewTarget() {
		return newTarget;
	}

	public void setNewTarget(HLNode newTarget) {
		this.newTarget = newTarget;
	}

	public HLArc getHLArc() {
		return hlArc;
	}

	public void setHLArc(HLArc hlArc) {
		this.hlArc = hlArc;
	}
}
