package roneditor.ronview.edit.parts;

import java.util.List;
import java.util.Vector;

import org.eclipse.draw2d.FreeformLayer;
import org.eclipse.draw2d.FreeformLayout;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.Label;
import org.eclipse.draw2d.LineBorder;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.Notifier;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.editparts.AbstractGraphicalEditPart;
import org.eclipse.gef.editpolicies.RootComponentEditPolicy;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.views.properties.IPropertySource;

import roneditor.IRonEditorConstants;
import roneditor.model.RONPropertySource;
import roneditor.ronview.edit.policies.RONViewEditPolicy;
import roneditor.ronview.edit.policies.RONViewXYLayoutEditPolicy;
import ronmodel.RON;

/**
 * EditPart for the main component "RON".
 */
public class RONEditPart extends AbstractGraphicalEditPart implements Adapter {
	protected IPropertySource propertySource = null;

	protected Notifier target;

	protected Label nameLabel;

	/**
	 * @param ron
	 */
	public RONEditPart(RON ron) {
		setModel(ron);
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#createFigure()
	 */
	protected IFigure createFigure() {
		FreeformLayer layer = new FreeformLayer();
		layer.setLayoutManager(new FreeformLayout());
		layer.setBorder(new LineBorder(1));
		return layer;
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
	 */
	protected void createEditPolicies() {

		installEditPolicy(EditPolicy.CONTAINER_ROLE, new RONViewEditPolicy());
		installEditPolicy(EditPolicy.LAYOUT_ROLE,
				new RONViewXYLayoutEditPolicy());
		installEditPolicy(EditPolicy.NODE_ROLE, null);
		installEditPolicy(EditPolicy.GRAPHICAL_NODE_ROLE, null);
		installEditPolicy(EditPolicy.SELECTION_FEEDBACK_ROLE, null);
		installEditPolicy(EditPolicy.COMPONENT_ROLE,
				new RootComponentEditPolicy());
	}

	/**
	 * @return the RON
	 */
	public RON getRON() {
		return (RON) getModel();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#getModelChildren()
	 */
	@SuppressWarnings("unchecked")
	protected List getModelChildren() {
		List children = new Vector();
		children.addAll(getRON().getNodes());
		return children;
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#activate()
	 */
	@SuppressWarnings("unchecked")
	public void activate() {
		if (isActive())
			return;

		// start listening for changes in the model
		getRON().eAdapters().add(this);
		nameLabel = new Label();
		nameLabel.setFont(JFaceResources
				.getFont(IRonEditorConstants.objectNetFontID));
		nameLabel.setForegroundColor(Display.getCurrent().getSystemColor(
				SWT.COLOR_GRAY));
		nameLabel.setText(getRON().getName());
		getFigure().add(nameLabel, new Rectangle(10, 10, -1, -1));
		super.activate();
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#deactivate()
	 */
	public void deactivate() {
		if (!isActive())
			return;

		// stop listening for changes in the model
		getRON().eAdapters().remove(this);

		super.deactivate();
	}

	/**
	 * @see org.eclipse.emf.common.notify.Adapter#getTarget()
	 */
	public Notifier getTarget() {
		return target;
	}

	/** 
	 * @see org.eclipse.emf.common.notify.Adapter#isAdapterForType(java.lang.Object)
	 */
	public boolean isAdapterForType(Object type) {
		return type.equals(getModel().getClass());
	}

	/** 
	 * @see org.eclipse.emf.common.notify.Adapter#setTarget(org.eclipse.emf.common.notify.Notifier)
	 */
	public void setTarget(Notifier newTarget) {
		target = newTarget;
	}

	/** 
	 * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
	 */
	public Object getAdapter(Class key) {
		/*
		 * override the default behavior defined in AbstractEditPart which would
		 * expect the model to be a property sourced. instead the editpart can
		 * provide a property source
		 */
		if (IPropertySource.class == key) {
			return getPropertySource();
		}
		return super.getAdapter(key);
	}

	protected IPropertySource getPropertySource() {
		if (propertySource == null) {
			propertySource = new RONPropertySource(getRON());
		}
		return propertySource;

	}

	/**
	 * Notify changes from the model to the view.
	 */
	public void notifyChanged(Notification notification) {
		int type = notification.getEventType();
		switch (type) {
		case Notification.ADD:
		case Notification.ADD_MANY:
		case Notification.REMOVE:
		case Notification.REMOVE_MANY:
			refreshChildren();
			break;
		case Notification.SET:
			nameLabel.setText(getRON().getName());
			refreshVisuals();
			break;
		}
	}
}
