package roneditor.ronview.edit.policies;

import org.eclipse.draw2d.Connection;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.editpolicies.BendpointEditPolicy;
import org.eclipse.gef.requests.BendpointRequest;

import roneditor.objectnetview.commands.AbstractBendpointCommand;

import roneditor.ronview.commands.CreateHLBendpointCommand;
import roneditor.ronview.commands.DeleteHLBendpointCommand;
import roneditor.ronview.commands.MoveHLBendpointCommand;
import ronmodel.HLArc;
/**
 * class for BendPointEditPolicy
 */
public class HLArcBendPointEditPolicy extends BendpointEditPolicy {
	/**
	 * @see org.eclipse.gef.editpolicies.BendpointEditPolicy#getCreateBendpointCommand(org.eclipse.gef.requests.BendpointRequest)
	 */
	protected Command getCreateBendpointCommand(BendpointRequest request) {
		AbstractBendpointCommand com = new CreateHLBendpointCommand();
		Point p = request.getLocation();
		Connection conn = getConnection();
		conn.translateToRelative(p);
		Point ref1 = conn.getSourceAnchor().getReferencePoint();
		Point ref2 = conn.getTargetAnchor().getReferencePoint();

		conn.translateToRelative(ref1);
		conn.translateToRelative(ref2);

		com.setRelativeDimensions(p.getDifference(ref1), p.getDifference(ref2));
		com.setHLArc((HLArc) request.getSource().getModel());
		com.setIndex(request.getIndex());
		return com;
	}
	/**
	 * @see org.eclipse.gef.editpolicies.BendpointEditPolicy#getDeleteBendpointCommand(org.eclipse.gef.requests.BendpointRequest)
	 */
	protected Command getDeleteBendpointCommand(BendpointRequest request) {

		AbstractBendpointCommand com = new DeleteHLBendpointCommand();
		Point p = request.getLocation();
		com.setLocation(p);
		com.setHLArc((HLArc) request.getSource().getModel());
		com.setIndex(request.getIndex());
		return com;
	}
	/**
	 * @see org.eclipse.gef.editpolicies.BendpointEditPolicy#getMoveBendpointCommand(org.eclipse.gef.requests.BendpointRequest)
	 */
	protected Command getMoveBendpointCommand(BendpointRequest request) {

		MoveHLBendpointCommand com = new MoveHLBendpointCommand();
		Point p = request.getLocation();
		Connection conn = getConnection();

		conn.translateToRelative(p);

		com.setLocation(p);

		Point ref1 = getConnection().getSourceAnchor().getReferencePoint();
		Point ref2 = getConnection().getTargetAnchor().getReferencePoint();

		conn.translateToRelative(ref1);
		conn.translateToRelative(ref2);

		com.setRelativeDimensions(p.getDifference(ref1), p.getDifference(ref2));
		com.setHLArc((HLArc) request.getSource().getModel());
		com.setIndex(request.getIndex());

		return com;
	}

}
