package roneditor.ronview.model;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.IPropertySource;
import org.eclipse.ui.views.properties.PropertyDescriptor;

import roneditor.model.NumberCellEditorValidator;
import ronmodel.HLPlace;

/**
 * Property source for {@link HLPlace}.
 */
public class HLPlacePropertySource implements IPropertySource {
	final public static int ID_NAME = 0;

	final public static int ID_X = 1;

	final public static int ID_Y = 2;

	final private static IPropertyDescriptor[] descriptors;

	static {
		final PropertyDescriptor nameProp = new PropertyDescriptor(Integer
				.valueOf(ID_NAME), "name");
		final PropertyDescriptor xProp = new PropertyDescriptor(Integer
				.valueOf(ID_X), "x");
		xProp.setValidator(NumberCellEditorValidator.instance(false));
		final PropertyDescriptor yProp = new PropertyDescriptor(Integer
				.valueOf(ID_Y), "y");
		yProp.setValidator(NumberCellEditorValidator.instance(false));
		descriptors = new IPropertyDescriptor[] { nameProp, xProp, yProp };
	}

	private HLPlace hlPlace;

	public HLPlacePropertySource(final HLPlace hlPlace) {
		this.hlPlace = hlPlace;
	}

	/**
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
	 */
	public Object getPropertyValue(final Object id) {
		switch (((Integer) id).intValue()) {
		case ID_NAME:
			return hlPlace.getName();
		case ID_X:
			return Integer.valueOf(hlPlace.getX()).toString();
		case ID_Y:
			return Integer.valueOf(hlPlace.getY()).toString();
		default:
			return null;
		}
	}

	/**
	 * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object,
	 *      java.lang.Object)
	 */
	public void setPropertyValue(final Object id, final Object value) {
		switch (((Integer) id).intValue()) {
		case ID_NAME:
			hlPlace.setName((String) value);
			break;
		case ID_X:
			hlPlace.setX(Integer.valueOf((String) value));
			break;
		case ID_Y:
			hlPlace.setY(Integer.valueOf((String) value));
			break;
		default:
		}
	}

	/**
	 * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
	 */
	public Object getEditableValue() {
		return hlPlace;
	}

	/**
	 * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
	 */
	public IPropertyDescriptor[] getPropertyDescriptors() {
		return descriptors;
	}

	/**
	 * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
	 */
	public void resetPropertyValue(final Object propName) {
	}

	/** 
	 * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
	 */
	public boolean isPropertySet(final Object propName) {
		return false;
	}

	/** 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "HLPlace(" + hlPlace.getName() + "," + hlPlace.getX() + ","
				+ hlPlace.getY() + ")";
	}

}
