package roneditor.ruleview;

import org.eclipse.gef.EditPartViewer;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.ui.actions.ActionFactory;

import roneditor.editor.ContextMenuProviderWithActionRegistry;
import roneditor.objectnetview.actions.EditAction;
import roneditor.ruleview.actions.CopyLHS2NACAction;
import roneditor.ruleview.actions.CopyLHS2RHSAction;
import roneditor.ruleview.actions.CopyRHS2NACAction;
import roneditor.ruleview.actions.CreateNACAction;
import roneditor.ruleview.actions.DeleteMappingAction;
import roneditor.ruleview.actions.DeleteNACAction;
import roneditor.ruleview.actions.SwitchNACAction;

/**
 * This is used to populate the context menu for the Viewers in the
 * {@link RuleNetPage}.
 * 
 * @author Tony Modica
 */
public class RulePageContextMenuProvider extends
		ContextMenuProviderWithActionRegistry {

	public RulePageContextMenuProvider(final EditPartViewer viewer,
			final ActionRegistry actionRegistry) {
		super(viewer, actionRegistry);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.gef.ContextMenuProvider#buildContextMenu(org.eclipse.jface.action.IMenuManager)
	 */
	@Override
	public void buildContextMenu(final IMenuManager menuManager) {
		GEFActionConstants.addStandardActionGroups(menuManager);

		// Actions in UNDO group
		String group = GEFActionConstants.GROUP_UNDO;
		appendActionToGroup(menuManager, ActionFactory.UNDO.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.REDO.getId(), group);

		// Actions in EDIT group
		group = GEFActionConstants.GROUP_EDIT;
		dynamicAppendActionToGroup(menuManager, GEFActionConstants.DIRECT_EDIT,
				group);
		appendActionToGroup(menuManager, ActionFactory.DELETE.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.COPY.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.CUT.getId(), group);
		appendActionToGroup(menuManager, ActionFactory.PASTE.getId(), group);

		// Sample Action to switch NACs
		dynamicAppendActionToGroup(menuManager, SwitchNACAction.ID,
				GEFActionConstants.GROUP_VIEW);

		appendActionToGroup(menuManager, EditAction.ID,
				GEFActionConstants.GROUP_ADD);
		dynamicAppendActionToGroup(menuManager, CopyLHS2RHSAction.ID,
				GEFActionConstants.GROUP_VIEW);
		dynamicAppendActionToGroup(menuManager, CopyLHS2NACAction.ID,
				GEFActionConstants.GROUP_VIEW);
		dynamicAppendActionToGroup(menuManager, CopyRHS2NACAction.ID,
				GEFActionConstants.GROUP_VIEW);
		dynamicAppendActionToGroup(menuManager, CreateNACAction.ID,
				GEFActionConstants.GROUP_VIEW);
		dynamicAppendActionToGroup(menuManager, DeleteNACAction.ID,
				GEFActionConstants.GROUP_VIEW);
		dynamicAppendActionToGroup(menuManager, DeleteMappingAction.ID,
				GEFActionConstants.GROUP_VIEW);
	}
}
