package roneditor.ruleview.actions;

import org.eclipse.gef.ui.actions.SelectionAction;
import org.eclipse.ui.IWorkbenchPart;

import roneditor.ruleview.RulePage;
import roneditor.ruleview.commands.SwitchNacCommand;

/**
 * This action is used by a {@link RulePage} and switches the NAC that is shown
 * in the first viewer.
 * 
 * @author Tony Modica
 */
public class SwitchNACAction extends SelectionAction {

	static public final String ID = "Switch NAC Action";

	private RulePage rulePage;

	public SwitchNACAction(IWorkbenchPart part, final RulePage rulePage) {
		super(part);
		this.rulePage = rulePage;
		setId(ID);
		setText("Switch NAC");
		setDescription("Switch NAC");
		setToolTipText("Switch NAC");
	}

	/**
	 * Change the contents of the viewer for the NACs (the left-most) to the
	 * next element in the list of the rule's NACs. If the last NAC is being
	 * shown switch to the first in the list.
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.action.Action#run()
	 */
	@Override
	public void run() {
		execute(new SwitchNacCommand(rulePage));
	}

	/**
	 * This action is only enabled for pages showing rules with at least 2 NACs.
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.action.Action#isEnabled()
	 */
	@Override
	protected boolean calculateEnabled() {
		return rulePage.getRule().getNacs().size() > 1;
	}
}
