package roneditor.ruleview.commands;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import org.eclipse.gef.commands.Command;

import roneditor.ruleview.model.RuleModelCreationFactory;
import roneditor.ruleview.model.RuleModelUtil;
import ronmodel.Codomain;
import ronmodel.LHS;
import ronmodel.Mapping;
import ronmodel.NAC;
import ronmodel.ONArc;
import ronmodel.ONNode;
import ronmodel.RHS;
/**
 * command fr Kopieren eines {@link RHS} in ein {@link NAC}
 */
public class CopyRHS2NACCommand extends Command {

	private static final String copyCommand_Label = "Copy RHS to NAC";

	protected RHS rhs;

	protected NAC nac;

	/**
	 * Constructor.
	 */
	public CopyRHS2NACCommand() {
		super(copyCommand_Label);
	}

	/**
	 * True if the command can be executed, false otherwise.
	 */
	public boolean canExecute() {
		if (rhs == null || nac == null || !nac.getNodes().isEmpty()
				|| rhs.getNodes().isEmpty())
			return false;
		return true;
	}

	/**
	 * Entry point for the command execution.
	 * der Inhalt von {@link LHS} wird in einem {@link Codomain} Kopiert
	 */
	public void execute() {
		Map<ONNode, ONNode> mappings = new HashMap<ONNode, ONNode>();
		ONNode onNode1 = null;
		ONNode onNode2 = null;
		RuleModelCreationFactory f = new RuleModelCreationFactory(Mapping.class);
		for (Object o : rhs.getNodes()) {
			onNode1 = (ONNode) o;
			onNode2 = RuleModelUtil.copy(onNode1);
			onNode2.setObjectNet(nac);
			mappings.put(onNode1, onNode2);
		}
		ONArc onArc1 = null;
		ONArc onArc2 = null;
		for (Object o : rhs.getArcs()) {
			onArc1 = (ONArc) o;
			onArc2 = RuleModelUtil.copy(onArc1);
			onArc2.setSource(mappings.get(onArc1.getSource()));
			onArc2.setTarget(mappings.get(onArc1.getTarget()));
			onArc2.setObjectNet(nac);
		}
		Mapping mapping1 = null;
		Mapping mapping2 = null;
		for (Object o : rhs.getMappings()) {
			mapping1 = (Mapping) o;
			mapping2 = (Mapping) f.getNewObject();
			mapping2.setSource(mapping1.getSource());
			mapping2.setTarget(mappings.get(mapping1.getTarget()));
			mapping2.setCodomain(nac);
		}
	}

	/**
	 * Returns the command label.
	 */
	public String getLabel() {
		return "Copy R->NAC";
	}

	/**
	 * Redo command execution.
	 */
	public void redo() {
		execute();
	}

	/**
	 * Undo command execution.
	 */
	public void undo() {
		Mapping mapping = null;
		List tmpList = new LinkedList(nac.getMappings());
		for (Object o : tmpList) {
			mapping = (Mapping) o;
			mapping.setSource(null);
			mapping.setTarget(null);
			mapping.setCodomain(null);
		}
		ONArc arc = null;
		tmpList.clear();
		tmpList.addAll(nac.getArcs());
		for (Object o : tmpList) {
			arc = (ONArc) o;
			arc.setSource(null);
			arc.setTarget(null);
			arc.setObjectNet(null);
		}
		ONNode node = null;
		tmpList.clear();
		tmpList.addAll(nac.getNodes());
		for (Object o : tmpList) {
			node = (ONNode) o;
			node.setObjectNet(null);
		}
	}

	public void setNac(NAC nac) {
		this.nac = nac;
	}

	public void setRhs(RHS rhs) {
		this.rhs = rhs;
	}

}
