package roneditor.ruleview.edit.parts;

import java.util.List;
import java.util.Vector;

import org.eclipse.emf.common.notify.Notification;
import org.eclipse.gef.EditPolicy;

import roneditor.objectnetview.edit.policies.ONNodeComponentEditPolicy;
import roneditor.ruleview.edit.policies.ONNodeEditPolicy;
import ronmodel.ONPlace;
import ronmodel.RonmodelPackage;

/**
 * EditPart for a {@link ONPlace}.
 */
public class ONPlaceEditPart extends
		roneditor.objectnetview.edit.parts.ONPlaceEditPart {

	/**
	 * Creates a new {@link ONPlaceEditPart} instance.
	 * 
	 * @param onPlace
	 */
	public ONPlaceEditPart(ONPlace onPlace) {
		super(onPlace);
	}
	/**
	 * @see roneditor.objectnetview.edit.parts.ONPlaceEditPart#getModelSourceConnections()
	 */
	@Override
	protected List getModelSourceConnections() {
		List sourceConnections = new Vector();
		sourceConnections.addAll(super.getModelSourceConnections());
		// sourceConnections.addAll(getONPlace().getIncomingMappings());
		return sourceConnections;
	}
	/**
	 * @see roneditor.objectnetview.edit.parts.ONPlaceEditPart#getModelTargetConnections()
	 */
	@Override
	protected List getModelTargetConnections() {
		List targetConnections = new Vector();
		targetConnections.addAll(super.getModelTargetConnections());
		// targetConnections.addAll(getONPlace().getOutgoingMappings());
		return targetConnections;
	}

	/**
	 * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
	 */
	protected void createEditPolicies() {
		// install the edit policy to handle connection creation
		installEditPolicy(EditPolicy.GRAPHICAL_NODE_ROLE,
				new ONNodeEditPolicy());
		// install the edit policy to handle deletion
		installEditPolicy(EditPolicy.COMPONENT_ROLE,
				new ONNodeComponentEditPolicy());
	}

	/**
	 * @see roneditor.objectnetview.edit.parts.ONPlaceEditPart#notifyChanged(org.eclipse.emf.common.notify.Notification)
	 */
	public void notifyChanged(Notification notification) {
		int featureId = notification.getFeatureID(RonmodelPackage.class);
		switch (featureId) {
		case RonmodelPackage.ON_NODE__OUTGOING_MAPPINGS:
			refreshVisuals();
			refreshTargetConnections();
			break;
		case RonmodelPackage.ON_NODE__INCOMING_MAPPINGS:
			refreshVisuals();
			refreshSourceConnections();
			break;
		default:
			super.notifyChanged(notification);
		}
	}
}
