package roneditor.ruleview.edit.parts;

import java.util.HashMap;

import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.emf.common.notify.Notification;

import roneditor.AbstractMultiViewerPage.MultiViewerPageViewer;
import roneditor.objectnetview.edit.parts.ObjectNetEditPart;
import roneditor.ruleview.RulePage;
import roneditor.ruleview.model.RuleModelUtil;
import ronmodel.Mapping;
import ronmodel.ONPlace;
import ronmodel.RHS;
/**
 * editpart for a RHS
 */
public class RHSEditPart extends ObjectNetEditPart {
	protected HashMap<Mapping, IMarker> markers = new HashMap<Mapping, IMarker>();

	public RHSEditPart(RHS rhs) {
		super(rhs);
	}

	/**
	 * bei nderungen im Modell werden alle markern 
	 * aktualisiert
	 */
	public void refreshMarkers() {
		if (getViewer() instanceof MultiViewerPageViewer) {
			RHS rhs = (RHS) getModel();
			Mapping mapping = null;
			removeAllMarker();
			for (Object o : rhs.getMappings()) {
				mapping = (Mapping) o;
				if (!RuleModelUtil.checkMapping(mapping)) {
					addMarker(mapping);
				}
			}
		}		
	}

	/**
	 * eine Marker fr dieses mapping einfgen
	 */
	public void addMarker(Mapping mapping) {
		if (!markers.containsKey(mapping)) {
			MultiViewerPageViewer viewer = (MultiViewerPageViewer) getViewer();
			RulePage page = (RulePage) viewer.getHostPage();
			IResource resource = (IResource) page.getEditor().getAdapter(
					IResource.class);
			String sourceClass = mapping.getSource() instanceof ONPlace ? "Place"
					: "Transition";
			String location = "Rule: " + page.getRule().getName() + "/"
					+ "RHS: " + mapping.getCodomain().getName() + "/"
					+ "MappingID: " + mapping.getSource().getMappingID() + "/"
					+ "Source: " + sourceClass + "-"
					+ mapping.getSource().getName() + "/" + "Target: "
					+ sourceClass + "-" + mapping.getTarget().getName();
			try {
				IMarker marker = resource.createMarker(IMarker.PROBLEM);
				marker.setAttribute(IMarker.MESSAGE, location + ": ERROR");
				marker.setAttribute(IMarker.SEVERITY, IMarker.SEVERITY_ERROR);
				marker.setAttribute(IMarker.LOCATION, location);
				markers.put(mapping, marker);
			} catch (CoreException e) {
				throw new RuntimeException(e);
			}
		}
	}

	/**
	 * ein Marker fr dieses Mapping lschen
	 */
	public void removeMarker(Mapping mapping) {
		IMarker marker = markers.remove(mapping);
		if (marker != null) {
			try {
				marker.delete();
			} catch (CoreException e) {
				throw new RuntimeException(e);
			}
		}
	}

	/**
	 * Alle Markers werden gelscht
	 */
	public void removeAllMarker() {
		try {
			for (IMarker marker : markers.values()) {
				marker.delete();
			}
			markers.clear();
		} catch (CoreException e) {
			throw new RuntimeException();
		}

	}
	/**
	 * @see roneditor.objectnetview.edit.parts.ObjectNetEditPart#notifyChanged(org.eclipse.emf.common.notify.Notification)
	 */
	@Override
	public void notifyChanged(Notification notification) {
		if (notification == null) {
			refreshMarkers();
			return;
		}
		int type = notification.getEventType();
		switch (type) {
		case Notification.ADD:
		case Notification.ADD_MANY:
		case Notification.REMOVE:
		case Notification.REMOVE_MANY:
			refreshChildren();
			refreshMarkers();
			break;
		case Notification.SET:
			nameLabel.setText(getObjectNet().getName());
			refreshVisuals();
			break;
		}
	}
	/**
	 * @see roneditor.objectnetview.edit.parts.ObjectNetEditPart#activate()
	 */
	@Override
	public void activate() {
		super.activate();
		refreshMarkers();
	}
	/**
	 * @see roneditor.objectnetview.edit.parts.ObjectNetEditPart#deactivate()
	 */
	@Override
	public void deactivate() {
		super.deactivate();
		removeAllMarker();
	}
}
